# copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
# this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu

set rcsId {$Id: lastwish.tcl,v 2.1 1999/08/28 08:32:57 jfontain Exp $}

class lastWish {

    proc lastWish {this command} {
        set ($this,command) $command
    }

    proc ~lastWish {this} {
        uplevel #0 $($this,command)                                                         ;# always invoke command at global level
    }

}
